@@ -10,8 +10,11 @@ LOGGER = logging.getLogger(__name__)
 
 def compute_in_parallel(series, func, **kwargs):
     num_cores = multiprocessing.cpu_count() - 1
-    results = Parallel(n_jobs=num_cores, backend="multiprocessing", prefer="processes")(
-        delayed(func)(series.iloc[i], **kwargs) for i in tqdm(range(series.shape[0]))
+    results = Parallel(
+        n_jobs=num_cores, backend="multiprocessing", prefer="processes"
+    )(
+        delayed(func)(series.iloc[i], **kwargs)
+        for i in tqdm(range(series.shape[0]))
     )
     return results
 
